==> pagedesigner-2.0.0-rc2.tar.gz: pagedesigner/src/Plugin/DataType/PagedesignerData.php <==
<?php

namespace Drupal\pagedesigner\Plugin\DataType;

use Drupal\Core\TypedData\TypedData;
use Drupal\pagedesigner\Entity\Element;

/**
 * A computed property for pagedesigner content data.
 *
 * @DataType(
 *   id = "pagedesigner_item_data",
 *   label = @Translation("Pagedesigner content data"),
 *   description = @Translation("Generated content of the pagedesigner."),
 * )
 */
class PagedesignerData extends TypedData {

  /**
   * Cached processed text.
   *
   * @var string|null
   */
  protected $value = NULL;

  /**
   * Cached processed text.
   *
   * @var string|null
   */
  protected $processed = NULL;

  /**
   * {@inheritdoc}
   */
  public function getValue() {
    if ($this->processed == NULL) {
      $language = $this->getParent()->getEntity()->language()->getId();
      $this->processed = $this->getContent($this->getParent()->target_id, $language);
    }
    return $this->processed;
  }

  /**
   *
   */
  public function getContent($containerId, $langcode, $published = TRUE) {
    if (\is_numeric($containerId)) {
      $container = Element::load($containerId);
      $container = ($published) ? $container->loadNewestPublished() : $container;
      if ($container != NULL && $container->hasTranslation($langcode)) {
        $list = [];
        $container = $container->getTranslation($langcode);
        $this->processed = \Drupal::service('pagedesigner.service.element_handler')->getContent($container, $list, $published);
      }
    }
    return $this->processed;
  }

  /**
   * {@inheritdoc}
   */
  public function setValue($value, $notify = TRUE) {
    $this->processed = $value;

    // Notify the parent of any changes.
    if ($notify && isset($this->parent)) {
      $this->parent->onChange($this->name);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getString() {
    return implode(' ', $this->getValue());
  }

}

==> pagedesigner-2.0.2.tar.gz: pagedesigner/src/Plugin/DataType/PagedesignerData.php <==
<?php

namespace Drupal\pagedesigner\Plugin\DataType;

use Drupal\Core\TypedData\TypedData;
use Drupal\pagedesigner\Entity\Element;

/**
 * A computed property for pagedesigner content data.
 *
 * @DataType(
 *   id = "pagedesigner_item_data",
 *   label = @Translation("Pagedesigner content data"),
 *   description = @Translation("Generated content of the pagedesigner."),
 * )
 */
class PagedesignerData extends TypedData {

  /**
   * Cached processed text.
   *
   * @var string|null
   */
  protected $value = NULL;

  /**
   * Cached processed text.
   *
   * @var string|null
   */
  protected $processed = NULL;

  /**
   * {@inheritdoc}
   */
  public function getValue() {
    if ($this->processed == NULL) {
      $language = $this->getParent()->getEntity()->language()->getId();
      $this->processed = $this->getContent($this->getParent()->target_id, $language);
    }
    return $this->processed;
  }

  /**
   * Returns the text content of the tree as a list.
   *
   * @param int $root_id
   *   The id of the root element.
   * @param string $langcode
   *   The desired language.
   * @param bool $published
   *   Whether to return the published or editing text.
   *
   * @return string
   *   The text content of the tree.
   */
  public function getContent(int $root_id, string $langcode, bool $published = TRUE) {
    if (\is_numeric($root_id)) {
      $root = Element::load($root_id);
      $root = ($published) ? $root->loadNewestPublished() : $root;
      if ($root != NULL && $root->hasTranslation($langcode)) {
        $list = [];
        $root = $root->getTranslation($langcode);
        $this->processed = \Drupal::service('pagedesigner.service.element_handler')->getContent($root, $list, $published);
      }
    }
    return $this->processed;
  }

  /**
   * {@inheritdoc}
   */
  public function setValue($value, $notify = TRUE) {
    $this->processed = $value;

    // Notify the parent of any changes.
    if ($notify && isset($this->parent)) {
      $this->parent->onChange($this->name);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getString() {
    return implode(' ', $this->getValue());
  }

}
